==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/cstp/leechcraft_cstp_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>Ajouter une tâche</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>URL :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>Chemin local :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>Parcourir…</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>Nom de fichier :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>Commentaire :</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>Le répertoire %1 n&apos;existe pas, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>Le répertoire %1 n&apos;est pas lisible, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>Impossible d&apos;écrire dans le répertoire %1, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation>%1 n&apos;est pas un répertoire, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation>Sélectionner un répertoire</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="206"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="213"/>
        <source>Remove all</source>
        <translation>Tout supprimer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="222"/>
        <source>Start</source>
        <translation>Lancer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="229"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="236"/>
        <source>Start all</source>
        <translation>Tout démarrer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="243"/>
        <source>Stop all</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="255"/>
        <source>File exists</source>
        <translation>Le fichier existe</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="256"/>
        <source>File %1 already exists, continue download?</source>
        <translation>Le fichier %1 existe déjà, continuer à télécharger ?</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="60"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>State</source>
        <translation>État</translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>Progress</source>
        <translation>Avancement</translation>
    </message>
    <message>
        <location filename="core.cpp" line="276"/>
        <source>Could not truncate file </source>
        <translation>Impossible de découper le fichier </translation>
    </message>
    <message>
        <location filename="core.cpp" line="405"/>
        <source>%1 (ETA: %2)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="417"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="421"/>
        <source>/s</source>
        <translation>/s</translation>
    </message>
    <message>
        <location filename="core.cpp" line="423"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="core.cpp" line="509"/>
        <source>Could not open file %1: %2</source>
        <translation>Impossible d&apos;ouvrir le fichier %1: %2</translation>
    </message>
    <message>
        <location filename="core.cpp" line="568"/>
        <source>Download finished: %1
%2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation>Inactif</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="202"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="task.cpp" line="204"/>
        <source>Finished</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="task.cpp" line="206"/>
        <source>Running</source>
        <translation>En cours</translation>
    </message>
    <message>
        <location filename="task.cpp" line="227"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>La tâche n&apos;est pas initialisée correctement</translation>
    </message>
    <message>
        <location filename="task.cpp" line="406"/>
        <source>Error writing to file %1: %2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.65.tar.bz2: leechcraft-0.4.65/src/plugins/cstp/leechcraft_cstp_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fr">
<context>
    <name>AddTask</name>
    <message>
        <location filename="addtask.ui" line="13"/>
        <source>Add task</source>
        <translation>Ajouter une tâche</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="21"/>
        <source>URL:</source>
        <translation>URL :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="31"/>
        <source>Local path:</source>
        <translation>Chemin local :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="43"/>
        <source>Browse...</source>
        <translation>Parcourir…</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="55"/>
        <source>Filename:</source>
        <translation>Nom de fichier :</translation>
    </message>
    <message>
        <location filename="addtask.ui" line="65"/>
        <source>Comment:</source>
        <translation>Commentaire :</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::AddTask</name>
    <message>
        <location filename="addtask.cpp" line="107"/>
        <source>Directory %1 doesn&apos;t exist, would you like to select another?</source>
        <translation>Le répertoire %1 n&apos;existe pas, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="110"/>
        <source>Directory %1 isn&apos;t readable, would you like to select another?</source>
        <translation>Le répertoire %1 n&apos;est pas lisible, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="113"/>
        <source>Directory %1 isn&apos;t writable, would you like to select another?</source>
        <translation>Impossible d&apos;écrire dans le répertoire %1, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="116"/>
        <source>%1 isn&apos;t a directory at all, would you like to select another?</source>
        <translation>%1 n&apos;est pas un répertoire, souhaitez vous en sélectionner un autre ?</translation>
    </message>
    <message>
        <location filename="addtask.cpp" line="157"/>
        <source>Select directory</source>
        <translation>Sélectionner un répertoire</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::CSTP</name>
    <message>
        <location filename="cstp.cpp" line="206"/>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="213"/>
        <source>Remove all</source>
        <translation>Tout supprimer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="222"/>
        <source>Start</source>
        <translation>Lancer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="229"/>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="236"/>
        <source>Start all</source>
        <translation>Tout démarrer</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="243"/>
        <source>Stop all</source>
        <translation>Tout arrêter</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="255"/>
        <source>File exists</source>
        <translation>Le fichier existe</translation>
    </message>
    <message>
        <location filename="cstp.cpp" line="256"/>
        <source>File %1 already exists, continue download?</source>
        <translation>Le fichier %1 existe déjà, continuer à télécharger ?</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Core</name>
    <message>
        <location filename="core.cpp" line="61"/>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <location filename="core.cpp" line="62"/>
        <source>State</source>
        <translation>État</translation>
    </message>
    <message>
        <location filename="core.cpp" line="63"/>
        <source>Progress</source>
        <translation>Avancement</translation>
    </message>
    <message>
        <location filename="core.cpp" line="277"/>
        <source>Could not truncate file </source>
        <translation>Impossible de découper le fichier </translation>
    </message>
    <message>
        <location filename="core.cpp" line="417"/>
        <source>%1 (ETA: %2)</source>
        <translation>%1 (ETA : %2)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="429"/>
        <source>%1% (%2 of %3 at %4)</source>
        <translation>%1% (%2 de %3 à %4)</translation>
    </message>
    <message>
        <location filename="core.cpp" line="433"/>
        <source>/s</source>
        <translation>/s</translation>
    </message>
    <message>
        <location filename="core.cpp" line="521"/>
        <source>Could not open file %1: %2</source>
        <translation>Impossible d&apos;ouvrir le fichier %1: %2</translation>
    </message>
    <message>
        <location filename="core.cpp" line="580"/>
        <source>Download finished: %1
%2</source>
        <translation>Téléchargement terminé : %1
%2</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::MainViewDelegate</name>
    <message>
        <location filename="mainviewdelegate.cpp" line="71"/>
        <source>Idle</source>
        <translation>Inactif</translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::CSTP::Task</name>
    <message>
        <location filename="task.cpp" line="213"/>
        <source>Stopped</source>
        <translation>Arrêté</translation>
    </message>
    <message>
        <location filename="task.cpp" line="215"/>
        <source>Finished</source>
        <translation>Terminé</translation>
    </message>
    <message>
        <location filename="task.cpp" line="217"/>
        <source>Running</source>
        <translation>En cours</translation>
    </message>
    <message>
        <location filename="task.cpp" line="238"/>
        <source>Task isn&apos;t initialized properly</source>
        <translation>La tâche n&apos;est pas initialisée correctement</translation>
    </message>
    <message>
        <location filename="task.cpp" line="476"/>
        <source>Error writing to file %1: %2</source>
        <translation>Erreur lors de l&apos;écriture du fichier %1 : %2</translation>
    </message>
</context>
<context>
    <name>cstpsettings</name>
    <message>
        <location filename="dummy.cpp" line="2"/>
        <source>Local settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="3"/>
        <location filename="dummy.cpp" line="7"/>
        <source>Behavior</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="4"/>
        <source>Alert about errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="5"/>
        <source>Network settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="6"/>
        <source>General</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="8"/>
        <source>Use text transfer mode:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="9"/>
        <source>Identification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="10"/>
        <source>HTTP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="11"/>
        <source>Login:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="12"/>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="13"/>
        <source>Custom user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="14"/>
        <source>Predefined user agent:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="15"/>
        <source>Firefox 3.0.1 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="16"/>
        <source>Internet Explorer 6.0 on Windows XP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="17"/>
        <source>Internet Explorer 7.0 on Windows Vista</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="18"/>
        <source>Internet Explorer 4.0 on Windows 98</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="19"/>
        <source>Internet Explorer 2.0 on Windows 95</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="20"/>
        <source>Konqueror 4.0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="21"/>
        <source>SeaMonkey 1.1.11 on Linux i686</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="22"/>
        <source>Opera 9.52 on Linux x86_64</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="23"/>
        <source>Wget 1.9.1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="24"/>
        <source>w3m 0.5.2</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dummy.cpp" line="25"/>
        <source>Lynx 2.8.7 with OpenSSL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
